modify class

Constructors

modify({String? key, bool skip = false, Transformable? transform})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skip → bool
final
transform → Transformable?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited